@@ -53,10 +53,19 @@
 
 //////////////////////////////////////////
 /// SUPPORT MACRO
-#define DEF_EXT_NEW_DEL(cls)                                               \
-  void *operator new(size_t sz) { return ats_malloc(ext::sizeOf<cls>()); } \
-  void *operator new(size_t sz, void *ptr) { return ptr; }                 \
-  void operator delete(void *ptr) { free(ptr); }
+#define DEF_EXT_NEW_DEL(cls)               \
+  void *operator new(size_t)               \
+  {                                        \
+    return ats_malloc(ext::sizeOf<cls>()); \
+  }                                        \
+  void *operator new(size_t, void *ptr)    \
+  {                                        \
+    return ptr;                            \
+  }                                        \
+  void operator delete(void *ptr)          \
+  {                                        \
+    free(ptr);                             \
+  }
 
 //////////////////////////////////////////
 /// HELPER CLASSES
@@ -65,7 +74,7 @@
 // Has 'const_iterator' trait class
 template <typename T> class has_const_iterator
 {
-  template <typename U> static std::true_type check(typename U::const_iterator *);
+  template <typename U> static std::true_type  check(typename U::const_iterator *);
   template <typename U> static std::false_type check(...);
 
 public:
@@ -75,7 +84,7 @@ public:
 // Has 'super_type' trait class
 template <typename T> class has_super_type
 {
-  template <typename U> static std::true_type check(typename U::super_type *);
+  template <typename U> static std::true_type  check(typename U::super_type *);
   template <typename U> static std::false_type check(...);
 
 public:
@@ -89,9 +98,9 @@ public:
 // C API
 
 // context (internally FieldDesc*)
-typedef void const *ExtFieldContext;
-typedef void *DerivedPtr;
-typedef void *FieldPtr;
+using ExtFieldContext = const void *;
+using DerivedPtr      = void *;
+using FieldPtr        = void *;
 
 FieldPtr ExtFieldPtr(DerivedPtr derived, ExtFieldContext field_context, int *size = nullptr);
 
@@ -114,30 +123,25 @@ namespace details // internal stuff
 
   // forward declare friend functions used outside of details
   template <typename T> uintptr_t initRecurseSuper(T &, uintptr_t);
-  template <typename T> FieldPtr FieldPtrGet(Extendible<T> const &, details::FieldDesc const &);
+  template <typename T> FieldPtr  FieldPtrGet(Extendible<T> const &, details::FieldDesc const &);
 
   //////////////////////////////////////////
 
-  bool &
-  areFieldsFinalized()
-  {
-    static bool finalized = false;
-    return finalized;
-  }
+  bool &areFieldsFinalized();
 
   /////////////////////////////////////////////////////////////////////
   /// ext::details::FieldDesc - type erased field descriptor, with type specific std::functions
   struct FieldDesc {
-    Offest_t ext_loc_offset;        ///< byte offset to Extendible._ext_loc
-    Offest_t field_offset;          ///< byte offset from ext_loc to field
+    Offest_t        ext_loc_offset; ///< byte offset to Extendible._ext_loc
+    Offest_t        field_offset;   ///< byte offset from ext_loc to field
     std::type_index field_type_idx; ///< data type index
-    uint16_t size;                  ///< byte size of field
-    uint8_t align;                  ///< alignment of field
-    uint8_t mask;                   ///< mask for packed bit operations
+    uint16_t        size;           ///< byte size of field
+    uint8_t         align;          ///< alignment of field
+    uint8_t         mask;           ///< mask for packed bit operations
 
     // specialize the following
-    std::function<void(FieldPtr)> constructor;
-    std::function<void(FieldPtr)> destructor;
+    std::function<void(FieldPtr)>                     constructor;
+    std::function<void(FieldPtr)>                     destructor;
     std::function<void(std::ostream &, void const *)> serializer;
 
     FieldDesc() : field_type_idx(typeid(std::nullptr_t)) {}
@@ -148,12 +152,12 @@ namespace details // internal stuff
   class Schema
   {
   public:
-    std::unordered_map<std::string, FieldDesc> fields; ///< defined elements of the blob by name
-    size_t alloc_size                     = 0;         ///< bytes to allocate for fields
-    uint8_t alloc_align                   = 1;         ///< alignment of block
-    std::atomic<uint> cnt_constructed     = {0};       ///< the number of Extendible<Derived> created.
-    std::atomic<uint> cnt_fld_constructed = {0};       ///< the number of Extendible<Derived> that constructed fields.
-    std::atomic<uint> cnt_destructed      = {0};       ///< the number of Extendible<Derived> destroyed.
+    std::unordered_map<std::string, FieldDesc> fields;                ///< defined elements of the blob by name
+    size_t                                     alloc_size      = 0;   ///< bytes to allocate for fields
+    uint8_t                                    alloc_align     = 1;   ///< alignment of block
+    std::atomic<uint>                          cnt_constructed = {0}; ///< the number of Extendible<Derived> created.
+    std::atomic<uint> cnt_fld_constructed = {0}; ///< the number of Extendible<Derived> that constructed fields.
+    std::atomic<uint> cnt_destructed      = {0}; ///< the number of Extendible<Derived> destroyed.
 
   public:
     Schema() {}
@@ -163,10 +167,10 @@ namespace details // internal stuff
     bool no_instances() const; ///< returns true if there are no instances of Extendible<Derived_t>
     bool reset();              ///< clears all field definitions.
 
-    size_t fullSize(size_t base_size) const;       ///< returns sizeof memory allocated
-    void updateMemOffsets();                       ///< updates memory offsets, alignment, and total allocation size
-    void callConstructor(uintptr_t ext_start_ptr); ///< calls constructor for each field
-    void callDestructor(uintptr_t ext_start_ptr);  ///< call destructor for each field
+    size_t fullSize(size_t base_size) const;         ///< returns sizeof memory allocated
+    void   updateMemOffsets();                       ///< updates memory offsets, alignment, and total allocation size
+    void   callConstructor(uintptr_t ext_start_ptr); ///< calls constructor for each field
+    void   callDestructor(uintptr_t ext_start_ptr);  ///< call destructor for each field
 
   }; // end Schema struct
 } // namespace details
@@ -224,22 +228,22 @@ private:
     return uintptr_t(this) + ext_loc;
   }
 
-  template <typename T> friend T *create();
-  template <typename T> friend uintptr_t details::initRecurseSuper(T &, uintptr_t);
-  template <typename T> friend FieldPtr details::FieldPtrGet(Extendible<T> const &, details::FieldDesc const &);
+  template <typename T> friend T          *create();
+  template <typename T> friend uintptr_t   details::initRecurseSuper(T &, uintptr_t);
+  template <typename T> friend FieldPtr    details::FieldPtrGet(Extendible<T> const &, details::FieldDesc const &);
   template <typename T> friend std::string viewFormat(T const &, uintptr_t, int);
 };
 
 // define the static schema per derived type
 template <typename Derived_t> details::Schema Extendible<Derived_t>::schema;
 
-//####################################################
-//####################################################
-// UTILITY Functions
+// ####################################################
+// ####################################################
+//  UTILITY Functions
 
 //////////////////////////////////////////////////////
 /// HexToString function for serializing untyped C storage
-// TODO: use ts::bwf::As_Hex() after PR goes through
+// TODO: use swoc::bwf::As_Hex() after PR goes through
 inline void
 hexToStream(std::ostream &os, void const *buf, uint16_t size)
 {
@@ -269,9 +273,9 @@ serializeField(std::ostream &os, Field_t const &f)
     os << f;
   }
 }
-//####################################################
-//####################################################
-//####################################################
+// ####################################################
+// ####################################################
+// ####################################################
 
 /////////////////////////////////////////////////////////////////////
 // FieldId
@@ -280,10 +284,11 @@ template <typename Derived_t, typename Field_t> class FieldId
 {
 public:
   ext::details::FieldDesc const *desc = nullptr;
-  bool isValid() const;
+  bool                           isValid() const;
   FieldId(ext::details::FieldDesc const &);
   FieldId() {}
-  FieldId(FieldId const &) = default;
+  FieldId(FieldId const &)            = default;
+  FieldId &operator=(FieldId const &) = default;
 };
 
 namespace details
@@ -301,14 +306,14 @@ namespace details
 
   template <typename Derived_t, typename Field_t>
   Field_t const &
-  fieldGet(void const *fld_ptr, FieldId<Derived_t, Field_t> const &field)
+  fieldGet(void const *fld_ptr, FieldId<Derived_t, Field_t> const & /* field ATS_UNUSED */)
   {
     return *static_cast<Field_t const *>(fld_ptr);
   }
 
   template <typename Derived_t, typename Field_t>
   Field_t &
-  fieldSet(void *fld_ptr, FieldId<Derived_t, Field_t> const &field)
+  fieldSet(void *fld_ptr, FieldId<Derived_t, Field_t> const & /* field ATS_UNUSED */)
   {
     return *static_cast<Field_t *>(fld_ptr);
   }
@@ -360,10 +365,10 @@ namespace details
   /// Bool specializations
 
   template <typename Derived_t>
-  const bool
+  bool
   fieldGet(const void *fld_ptr, FieldId<Derived_t, bool> const &field)
   {
-    return bool((*static_cast<const uint8_t *>(fld_ptr)) & field.desc->mask);
+    return static_cast<bool>((*static_cast<const uint8_t *>(fld_ptr)) & field.desc->mask);
   }
 
   template <typename Derived_t>
@@ -396,7 +401,7 @@ namespace details
   /// std::atomic<bool> specializations (same as bool)
 
   template <typename Derived_t>
-  inline const bool
+  inline bool
   fieldGet(void const *fld_ptr, FieldId<Derived_t, std::atomic<bool>> const &field)
   {
     return bool(fld_ptr & field.mask);
@@ -447,10 +452,10 @@ FieldId<Derived_t, Field_t>::isValid() const
   return desc != nullptr;
 }
 
-//####################################################
-//####################################################
-//####################################################
-// Functional API for Extendible Field Access
+// ####################################################
+// ####################################################
+// ####################################################
+//  Functional API for Extendible Field Access
 //
 
 ////////////////////////////////////////////////////
@@ -511,8 +516,8 @@ fieldFind(FieldId<Derived_t, Field_t> &field_id, char const *field_name)
 {
   using namespace ext::details;
   ink_release_assert(areFieldsFinalized());
-  Schema const &schema = Extendible<Derived_t>::schema;
-  auto field_iter      = schema.fields.find(field_name);
+  Schema const &schema     = Extendible<Derived_t>::schema;
+  auto          field_iter = schema.fields.find(field_name);
   if (field_iter == schema.fields.end()) {
     return false; // didn't find name
   }
@@ -527,8 +532,8 @@ fieldFind(char const *field_name)
 {
   using namespace ext::details;
   ink_release_assert(areFieldsFinalized());
-  Schema const &schema = Extendible<Derived_t>::schema;
-  auto field_iter      = schema.fields.find(field_name);
+  Schema const &schema     = Extendible<Derived_t>::schema;
+  auto          field_iter = schema.fields.find(field_name);
   if (field_iter == schema.fields.end()) {
     return nullptr; // didn't find name
   }
@@ -541,8 +546,8 @@ template <typename T, typename Derived_t, typename Field_t>
 inline decltype(auto)
 get(T const &d, FieldId<Derived_t, Field_t> &field)
 {
-  Extendible<Derived_t> const &ext = d;
-  FieldPtr fld_ptr                 = ext::details::FieldPtrGet(ext, *field.desc);
+  Extendible<Derived_t> const &ext     = d;
+  FieldPtr                     fld_ptr = ext::details::FieldPtrGet(ext, *field.desc);
   return ext::details::fieldGet(fld_ptr, field);
 }
 
@@ -550,8 +555,8 @@ template <typename T, typename Derived_t, typename Field_t>
 inline decltype(auto)
 set(T &d, FieldId<Derived_t, Field_t> &field)
 {
-  Extendible<Derived_t> const &ext = d;
-  FieldPtr fld_ptr                 = ext::details::FieldPtrGet(ext, *field.desc);
+  Extendible<Derived_t> const &ext     = d;
+  FieldPtr                     fld_ptr = ext::details::FieldPtrGet(ext, *field.desc);
   return ext::details::fieldSet(fld_ptr, field);
 }
 
@@ -606,7 +611,7 @@ Extendible<Derived_t>::initFields(uintptr_t start_ptr)
   ink_assert(ext_loc == 0);
   start_ptr = ROUNDUP(start_ptr, schema.alloc_align); // pad the previous struct, so that our fields are memaligned correctly
   ink_assert(start_ptr - uintptr_t(this) < UINT16_MAX);
-  ext_loc = uint16_t(start_ptr - uintptr_t(this)); // store the offset to be used by ext::get and ext::set
+  ext_loc = static_cast<uint16_t>(start_ptr - uintptr_t(this)); // store the offset to be used by ext::get and ext::set
   ink_assert(ext_loc > 0);
   schema.callConstructor(start_ptr);    // construct all fields
   return start_ptr + schema.alloc_size; // return the end of the extendible data
@@ -617,16 +622,16 @@ namespace details
   /// recursively init all extendible structures, and construct fields
   template <typename Derived_t>
   uintptr_t
-  initRecurseSuper(Derived_t &devired, uintptr_t tail_ptr /*= 0*/)
+  initRecurseSuper(Derived_t &derived, uintptr_t tail_ptr /*= 0*/)
   {
-    // track a tail pointer, that starts after the class, and interate each extendible block
+    // track a tail pointer, that starts after the class, and iterate each extendible block
     if constexpr (has_super_type<Derived_t>::value) {
       // init super type, move tail pointer
-      tail_ptr = initRecurseSuper<typename Derived_t::super_type>(devired, tail_ptr);
+      tail_ptr = initRecurseSuper<typename Derived_t::super_type>(derived, tail_ptr);
     }
     if constexpr (std::is_base_of<Extendible<Derived_t>, Derived_t>::value) {
       // set start for this extendible block after the previous extendible, and move tail pointer to after this block
-      tail_ptr = devired.Extendible<Derived_t>::initFields(tail_ptr);
+      tail_ptr = derived.Extendible<Derived_t>::initFields(tail_ptr);
     }
     return tail_ptr;
   }
@@ -636,7 +641,7 @@ namespace details
 // allocate and initialize an extendible data structure
 template <typename Derived_t, typename... Args>
 Derived_t *
-create(Args &&... args)
+create(Args &&...args)
 {
   // don't instantiate until all Fields are finalized.
   ink_assert(ext::details::areFieldsFinalized());
@@ -682,11 +687,11 @@ viewFormat(T const &t, uintptr_t _base_addr = 0, int _full_size = ext::sizeOf<T>
   }
 
   if constexpr (is_base_of<Extendible<T>, T>::value) {
-    Extendible<T> const *e = &t;
-    int ptr_start          = uintptr_t(e) + Extendible<T>::getLocOffset() - _base_addr;
-    int ptr_end            = ptr_start + sizeof(typename Extendible<T>::short_ptr_t);
-    int ext_start          = e->getBegin() - _base_addr;
-    int ext_end            = Extendible<T>::schema.fullSize(ext_start);
+    Extendible<T> const *e         = &t;
+    int                  ptr_start = uintptr_t(e) + Extendible<T>::getLocOffset() - _base_addr;
+    int                  ptr_end   = ptr_start + sizeof(typename Extendible<T>::short_ptr_t);
+    int                  ext_start = e->getBegin() - _base_addr;
+    int                  ext_end   = Extendible<T>::schema.fullSize(ext_start);
 
     ink_assert(ptr_end <= ext_start);
     ink_assert(ext_end <= _full_size);
@@ -719,7 +724,7 @@ viewFormat(T const &t, uintptr_t _base_addr = 0, int _full_size = ext::sizeOf<T>
 
 namespace details
 {
-  std::string
+  inline std::string
   ltrim(std::string const &str, const std::string &chars = "\t\n\v\f\r ")
   {
     std::string r(str);
@@ -740,8 +745,8 @@ serialize(std::ostream &os, T const &t)
     if constexpr (has_super_type<T>::value) {
       serialize<typename T::super_type>(os, t);
     }
-    auto const &schema = T::schema;
-    size_t name_width  = 0;
+    auto const &schema     = T::schema;
+    size_t      name_width = 0;
     for (const auto &kv : schema.fields) {
       name_width = max(name_width, kv.first.length());
     }
@@ -769,22 +774,3 @@ toString(T const &t)
   return ss.str();
 }
 } // namespace ext
-
-// C API
-//
-
-FieldPtr
-ExtFieldPtr(DerivedPtr derived, ExtFieldContext field_context, int *size /*= nullptr*/)
-{
-  using namespace ext;
-  using namespace ext::details;
-  ink_assert(field_context);
-  ink_assert(derived);
-  FieldDesc const &desc = *static_cast<FieldDesc const *>(field_context);
-  if (size) {
-    *size = desc.size;
-  }
-
-  Offest_t const *loc = (Offest_t const *)(uintptr_t(derived) + desc.ext_loc_offset);
-  return FieldPtr(uintptr_t(derived) + (*loc) + desc.field_offset);
-}
