@@ -20,12 +20,14 @@
 
 #include "ts/ts.h"
 #include "ts/remap.h"
+#include "ts/remap_version.h"
 
 #include "policy_manager.h"
 #include "configs.h"
 
 const char *PLUGIN_NAME = "cache_promote";
-int TXN_ARG_IDX;
+int         TXN_ARG_IDX;
+DbgCtl      cache_promote_dbg_ctl{PLUGIN_NAME};
 
 // This has to be a global here. I tried doing a classic singleton (with a getInstance()) in the PolicyManager,
 // but then reloading the DSO does not work. What happens is that the old singleton is still there, even though
@@ -44,7 +46,7 @@ static PolicyManager gManager;
 static int
 cont_handle_policy(TSCont contp, TSEvent event, void *edata)
 {
-  TSHttpTxn txnp          = static_cast<TSHttpTxn>(edata);
+  TSHttpTxn        txnp   = static_cast<TSHttpTxn>(edata);
   PromotionConfig *config = static_cast<PromotionConfig *>(TSContDataGet(contp));
 
   switch (event) {
@@ -58,9 +60,9 @@ cont_handle_policy(TSCont contp, TSEvent event, void *edata)
         case TS_CACHE_LOOKUP_MISS:
         case TS_CACHE_LOOKUP_SKIPPED:
           if (config->getPolicy()->doSample() && config->getPolicy()->doPromote(txnp)) {
-            TSDebug(PLUGIN_NAME, "cache-status is %d, and leaving cache on (promoted)", obj_status);
+            DBG("cache-status is %d, and leaving cache on (promoted)", obj_status);
           } else {
-            TSDebug(PLUGIN_NAME, "cache-status is %d, and turning off the cache (not promoted)", obj_status);
+            DBG("cache-status is %d, and turning off the cache (not promoted)", obj_status);
             if (config->getPolicy()->countBytes()) {
               // Need to schedule this continuation for read-response-header-hook as well.
               TSHttpTxnHookAdd(txnp, TS_HTTP_READ_RESPONSE_HDR_HOOK, contp);
@@ -73,7 +75,7 @@ cont_handle_policy(TSCont contp, TSEvent event, void *edata)
           break;
         default:
           // Do nothing, just let it handle the lookup.
-          TSDebug(PLUGIN_NAME, "cache-status is %d (hit), nothing to do", obj_status);
+          DBG("cache-status is %d (hit), nothing to do", obj_status);
 
           if (config->getPolicy()->_stats_enabled) {
             TSStatIntIncrement(config->getPolicy()->_cache_hits_id, 1);
@@ -85,7 +87,7 @@ cont_handle_policy(TSCont contp, TSEvent event, void *edata)
         TSStatIntIncrement(config->getPolicy()->_total_requests_id, 1);
       }
     } else {
-      TSDebug(PLUGIN_NAME, "request is an internal (plugin) request, implicitly promoted");
+      DBG("request is an internal (plugin) request, implicitly promoted");
     }
     break;
 
@@ -100,7 +102,7 @@ cont_handle_policy(TSCont contp, TSEvent event, void *edata)
 
   // Should not happen
   default:
-    TSDebug(PLUGIN_NAME, "unhandled event %d", static_cast<int>(event));
+    DBG("unhandled event %d", static_cast<int>(event));
     break;
   }
 
@@ -115,16 +117,7 @@ cont_handle_policy(TSCont contp, TSEvent event, void *edata)
 TSReturnCode
 TSRemapInit(TSRemapInterface *api_info, char *errbuf, int errbuf_size)
 {
-  if (api_info->size < sizeof(TSRemapInterface)) {
-    strncpy(errbuf, "[tsremap_init] - Incorrect size of TSRemapInterface structure", errbuf_size - 1);
-    return TS_ERROR;
-  }
-
-  if (api_info->tsremap_version < TSREMAP_VERSION) {
-    snprintf(errbuf, errbuf_size, "[tsremap_init] - Incorrect API version %ld.%ld", api_info->tsremap_version >> 16,
-             (api_info->tsremap_version & 0xffff));
-    return TS_ERROR;
-  }
+  CHECK_REMAP_API_COMPATIBILITY(api_info, errbuf, errbuf_size);
 
   // Reserve a TXN slot for storing the calculated URL hash key
   if (TS_SUCCESS != TSUserArgIndexReserve(TS_USER_ARGS_TXN, PLUGIN_NAME, "cache_promote URL hash key", &TXN_ARG_IDX)) {
@@ -132,14 +125,14 @@ TSRemapInit(TSRemapInterface *api_info, char *errbuf, int errbuf_size)
     return TS_ERROR;
   }
 
-  TSDebug(PLUGIN_NAME, "remap plugin is successfully initialized, TXN_IDX = %d", TXN_ARG_IDX);
+  DBG("remap plugin is successfully initialized, TXN_IDX = %d", TXN_ARG_IDX);
   return TS_SUCCESS; /* success */
 }
 
 void
 TSRemapDone()
 {
-  TSDebug(PLUGIN_NAME, "called TSRemapDone()");
+  DBG("called TSRemapDone()");
   gManager.clear();
 }
 
@@ -166,7 +159,7 @@ TSRemapNewInstance(int argc, char *argv[], void **ih, char * /* errbuf */, int /
 void
 TSRemapDeleteInstance(void *ih)
 {
-  TSCont contp            = static_cast<TSCont>(ih);
+  TSCont           contp  = static_cast<TSCont>(ih);
   PromotionConfig *config = static_cast<PromotionConfig *>(TSContDataGet(contp));
 
   delete config; // This will return the PromotionPolicy to the PromotionManager as well
@@ -180,11 +173,11 @@ TSRemapStatus
 TSRemapDoRemap(void *ih, TSHttpTxn rh, TSRemapRequestInfo * /* ATS_UNUSED rri */)
 {
   if (nullptr == ih) {
-    TSDebug(PLUGIN_NAME, "no promotion rules configured, this is probably a plugin bug");
+    DBG("no promotion rules configured, this is probably a plugin bug");
   } else {
     TSCont contp = static_cast<TSCont>(ih);
 
-    TSDebug(PLUGIN_NAME, "scheduling a TS_HTTP_CACHE_LOOKUP_COMPLETE_HOOK hook");
+    DBG("scheduling a TS_HTTP_CACHE_LOOKUP_COMPLETE_HOOK hook");
     TSHttpTxnHookAdd(rh, TS_HTTP_CACHE_LOOKUP_COMPLETE_HOOK, contp);
   }
 
