@@ -19,13 +19,13 @@
 //
 // Interface for the config line parser
 //
-#ifndef __PARSER_H__
-#define __PARSER_H__ 1
+#pragma once
 
 #include <string>
 #include <vector>
 #include <algorithm>
 
+#include "ts/ts.h"
 #include "lulu.h"
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -33,65 +33,110 @@
 class Parser
 {
 public:
-  explicit Parser(const std::string &line);
+  Parser() = default; // No from/to URLs for this parser
+  Parser(char *from_url, char *to_url) : _from_url(from_url), _to_url(to_url) {}
+
+  // noncopyable
+  Parser(const Parser &)         = delete;
+  void operator=(const Parser &) = delete;
+
+  // These are not const char *, because, you know, everything else with argv is a char *
+  char *
+  from_url() const
+  {
+    return _from_url;
+  }
+
+  char *
+  to_url() const
+  {
+    return _to_url;
+  }
 
   bool
   empty() const
   {
     return _empty;
   }
+
   bool
   is_cond() const
   {
     return _cond;
   }
 
-  bool
-  cond_op_is(const std::string s) const
-  {
-    return _cond && (_op == s);
-  }
-  bool
-  oper_op_is(const std::string s) const
-  {
-    return !_cond && (_op == s);
-  }
-
   const std::string &
   get_op() const
   {
     return _op;
   }
+
   std::string &
   get_arg()
   {
     return _arg;
   }
+
   const std::string &
   get_value() const
   {
     return _val;
   }
 
-  bool
-  mod_exist(const std::string m) const
+  // Return a copy of the string, this implies RVO as well
+  std::string
+  copy_value() const
   {
-    return (std::find(_mods.begin(), _mods.end(), m) != _mods.end());
+    return _val;
   }
 
-private:
-  void preprocess(std::vector<std::string> tokens);
-  DISALLOW_COPY_AND_ASSIGN(Parser);
+  bool
+  mod_exist(const std::string &m) const
+  {
+    return std::find(_mods.begin(), _mods.end(), m) != _mods.end();
+  }
 
-  bool _cond;
-  bool _empty;
+  bool cond_is_hook(TSHttpHookID &hook) const;
+
+  const std::vector<std::string> &
+  get_tokens() const
+  {
+    return _tokens;
+  }
+
+  bool parse_line(const std::string &original_line);
+
+private:
+  bool preprocess(std::vector<std::string> tokens);
+
+  bool                     _cond     = false;
+  bool                     _empty    = false;
+  char                    *_from_url = nullptr;
+  char                    *_to_url   = nullptr;
   std::vector<std::string> _mods;
-  std::string _op;
-  std::string _arg;
-  std::string _val;
+  std::string              _op;
+  std::string              _arg;
+  std::string              _val;
 
 protected:
   std::vector<std::string> _tokens;
 };
 
-#endif // __PARSER_H
+class HRWSimpleTokenizer
+{
+public:
+  explicit HRWSimpleTokenizer(const std::string &line);
+
+  // noncopyable
+  HRWSimpleTokenizer(const HRWSimpleTokenizer &) = delete;
+  void operator=(const HRWSimpleTokenizer &)     = delete;
+
+  const std::vector<std::string> &
+  get_tokens() const
+  {
+    return _tokens;
+  }
+
+protected:
+  std::vector<std::string> _tokens;
+};
