@@ -45,18 +45,18 @@ class Resources
 public:
   explicit Resources(TSHttpTxn txnptr, TSCont contptr) : txnp(txnptr), contp(contptr)
   {
-    TSDebug(PLUGIN_NAME_DBG, "Calling CTOR for Resources (InkAPI)");
+    Dbg(dbg_ctl, "Calling CTOR for Resources (InkAPI)");
   }
 
   Resources(TSHttpTxn txnptr, TSRemapRequestInfo *rri) : txnp(txnptr), _rri(rri)
   {
-    TSDebug(PLUGIN_NAME_DBG, "Calling CTOR for Resources (RemapAPI)");
+    Dbg(dbg_ctl, "Calling CTOR for Resources (RemapAPI)");
   }
 
   ~Resources() { destroy(); }
 
   // noncopyable
-  Resources(const Resources &) = delete;
+  Resources(const Resources &)      = delete;
   void operator=(const Resources &) = delete;
 
   void gather(const ResourceIDs ids, TSHttpHookID hook);
@@ -66,15 +66,15 @@ public:
     return _ready;
   }
 
-  TSHttpTxn txnp;
-  TSCont contp             = nullptr;
-  TSRemapRequestInfo *_rri = nullptr;
-  TSMBuffer bufp           = nullptr;
-  TSMLoc hdr_loc           = nullptr;
-  TSMBuffer client_bufp    = nullptr;
-  TSMLoc client_hdr_loc    = nullptr;
-  TSHttpStatus resp_status = TS_HTTP_STATUS_NONE;
-  bool changed_url         = false;
+  TSHttpTxn           txnp;
+  TSCont              contp          = nullptr;
+  TSRemapRequestInfo *_rri           = nullptr;
+  TSMBuffer           bufp           = nullptr;
+  TSMLoc              hdr_loc        = nullptr;
+  TSMBuffer           client_bufp    = nullptr;
+  TSMLoc              client_hdr_loc = nullptr;
+  TSHttpStatus        resp_status    = TS_HTTP_STATUS_NONE;
+  bool                changed_url    = false;
 
 private:
   void destroy();
