@@ -93,6 +93,10 @@ uriEncode(const String &in, bool isObjectName)
     } else if (isObjectName && i == '/') {
       /* Encode the forward slash character, '/', everywhere except in the object key name. */
       result << "/";
+    } else if (i == '+') {
+      /* Only written in the example code, but a plus sign is treated as a space regardless of the position and it must be encoded
+       * as "%20" instead of "%2B" */
+      result << "%20";
     } else {
       /* Letters in the hexadecimal value must be upper-case, for example "%1A". */
       result << "%" << std::uppercase << std::setfill('0') << std::setw(2) << std::hex << static_cast<int>(i);
@@ -186,8 +190,8 @@ trimWhiteSpacesAndSqueezeInnerSpaces(const char *in, size_t inLen)
   String in_str = trimWhiteSpaces(String(in, inLen));
   String out_str;
   out_str.reserve(in_str.size());
-  size_t n    = 0;
-  char prev_c = '\0';
+  size_t n      = 0;
+  char   prev_c = '\0';
 
   for (auto &c : in_str) {
     if (!isspace(c)) {
@@ -213,7 +217,7 @@ trimWhiteSpaces(const String &s)
 {
   /* @todo do this better? */
   static const String whiteSpace = " \t\n\v\f\r";
-  size_t start                   = s.find_first_not_of(whiteSpace);
+  size_t              start      = s.find_first_not_of(whiteSpace);
   if (String::npos == start) {
     return String();
   }
@@ -290,10 +294,10 @@ String
 getCanonicalRequestSha256Hash(TsInterface &api, bool signPayload, const StringSet &includeHeaders, const StringSet &excludeHeaders,
                               String &signedHeaders)
 {
-  int length;
-  const char *str = nullptr;
+  int           length;
+  const char   *str = nullptr;
   unsigned char canonicalRequestSha256Hash[SHA256_DIGEST_LENGTH];
-  SHA256_CTX canonicalRequestSha256Ctx;
+  SHA256_CTX    canonicalRequestSha256Ctx;
 
   SHA256_Init(&canonicalRequestSha256Ctx);
 
@@ -311,11 +315,6 @@ getCanonicalRequestSha256Hash(TsInterface &api, bool signPayload, const StringSe
   str = api.getPath(&length);
   String path("/");
   path.append(str, length);
-  str = api.getParams(&length);
-  if (length > 0) {
-    path.append(";", 1);
-    path.append(str, length);
-  }
   String canonicalUri = canonicalEncode(path, /* isObjectName */ true);
   sha256Update(&canonicalRequestSha256Ctx, canonicalUri);
   sha256Update(&canonicalRequestSha256Ctx, "\n");
@@ -324,16 +323,16 @@ getCanonicalRequestSha256Hash(TsInterface &api, bool signPayload, const StringSe
    * <CanonicalQueryString>\n */
   const char *query = api.getQuery(&length);
 
-  StringSet paramNames;
-  StringMap paramsMap;
+  StringSet          paramNames;
+  StringMap          paramsMap;
   std::istringstream istr(String(query, length));
-  String token;
-  StringSet container;
+  String             token;
+  StringSet          container;
 
   while (std::getline(istr, token, '&')) {
     String::size_type pos(token.find_first_of('='));
-    String param(token.substr(0, pos == String::npos ? token.size() : pos));
-    String value(pos == String::npos ? "" : token.substr(pos + 1, token.size()));
+    String            param(token.substr(0, pos == String::npos ? token.size() : pos));
+    String            value(pos == String::npos ? "" : token.substr(pos + 1, token.size()));
 
     String encodedParam = canonicalEncode(param, /* isObjectName */ false);
     paramNames.insert(encodedParam);
@@ -357,8 +356,8 @@ getCanonicalRequestSha256Hash(TsInterface &api, bool signPayload, const StringSe
   StringMap headersMap;
 
   for (HeaderIterator it = api.headerBegin(); it != api.headerEnd(); it++) {
-    int nameLen;
-    int valueLen;
+    int         nameLen;
+    int         valueLen;
     const char *name  = it.getName(&nameLen);
     const char *value = it.getValue(&valueLen);
 
@@ -595,8 +594,6 @@ getRegion(const StringMap &regionMap, const char *entryPoint, size_t entryPointL
  *
  * @see AWS spec: http://docs.aws.amazon.com/AmazonS3/latest/API/sig-v4-header-based-auth.html
 
- * @param entryPoint  entry-point name
- * @param entryPointLen entry-point name length
  * @param dateTime - ISO 8601 time
  * @param dateTimeLen - ISO 8601 time length
  * @param region AWS region name
@@ -608,8 +605,8 @@ getRegion(const StringMap &regionMap, const char *entryPoint, size_t entryPointL
  * @returns the string to sign
  */
 String
-getStringToSign(const char *entryPoint, size_t EntryPointLen, const char *dateTime, size_t dateTimeLen, const char *region,
-                size_t regionLen, const char *service, size_t serviceLen, const char *sha256Hash, size_t sha256HashLen)
+getStringToSign(const char *dateTime, size_t dateTimeLen, const char *region, size_t regionLen, const char *service,
+                size_t serviceLen, const char *sha256Hash, size_t sha256HashLen)
 {
   String stringToSign;
 
@@ -660,17 +657,17 @@ getSignature(const char *awsSecret, size_t awsSecretLen, const char *awsRegion,
              size_t awsServiceLen, const char *dateTime, size_t dateTimeLen, const char *stringToSign, size_t stringToSignLen,
              char *signature, size_t signatureLen)
 {
-  unsigned int dateKeyLen = EVP_MAX_MD_SIZE;
+  unsigned int  dateKeyLen = EVP_MAX_MD_SIZE;
   unsigned char dateKey[EVP_MAX_MD_SIZE];
-  unsigned int dateRegionKeyLen = EVP_MAX_MD_SIZE;
+  unsigned int  dateRegionKeyLen = EVP_MAX_MD_SIZE;
   unsigned char dateRegionKey[EVP_MAX_MD_SIZE];
-  unsigned int dateRegionServiceKeyLen = EVP_MAX_MD_SIZE;
+  unsigned int  dateRegionServiceKeyLen = EVP_MAX_MD_SIZE;
   unsigned char dateRegionServiceKey[EVP_MAX_MD_SIZE];
-  unsigned int signingKeyLen = EVP_MAX_MD_SIZE;
+  unsigned int  signingKeyLen = EVP_MAX_MD_SIZE;
   unsigned char signingKey[EVP_MAX_MD_SIZE];
 
   size_t keyLen = 4 + awsSecretLen;
-  char key[keyLen];
+  char   key[keyLen];
   memcpy(key, "AWS4", 4);
   memcpy(key + 4, awsSecret, awsSecretLen);
 
@@ -729,18 +726,18 @@ AwsAuthV4::getAuthorizationHeader()
   String signedHeaders;
   String canonicalReq = getCanonicalRequestSha256Hash(_api, _signPayload, _includedHeaders, _excludedHeaders, signedHeaders);
 
-  int hostLen      = 0;
-  const char *host = _api.getHost(&hostLen);
+  int         hostLen = 0;
+  const char *host    = _api.getHost(&hostLen);
 
   String awsRegion = getRegion(_regionMap, host, hostLen);
 
-  String stringToSign = getStringToSign(host, hostLen, _dateTime, sizeof(_dateTime) - 1, awsRegion.c_str(), awsRegion.length(),
-                                        _awsService, _awsServiceLen, canonicalReq.c_str(), canonicalReq.length());
+  String stringToSign = getStringToSign(_dateTime, sizeof(_dateTime) - 1, awsRegion.c_str(), awsRegion.length(), _awsService,
+                                        _awsServiceLen, canonicalReq.c_str(), canonicalReq.length());
 #ifdef AWS_AUTH_V4_DETAILED_DEBUG_OUTPUT
   std::cout << "<StringToSign>" << stringToSign << "</StringToSign>" << std::endl;
 #endif
 
-  char signature[EVP_MAX_MD_SIZE];
+  char   signature[EVP_MAX_MD_SIZE] = "";
   size_t signatureLen =
     getSignature(_awsSecretAccessKey, _awsSecretAccessKeyLen, awsRegion.c_str(), awsRegion.length(), _awsService, _awsServiceLen,
                  _dateTime, 8, stringToSign.c_str(), stringToSign.length(), signature, EVP_MAX_MD_SIZE);
@@ -753,9 +750,7 @@ AwsAuthV4::getAuthorizationHeader()
   std::stringstream authorizationHeader;
   authorizationHeader << "AWS4-HMAC-SHA256 ";
   authorizationHeader << "Credential=" << String(_awsAccessKeyId, _awsAccessKeyIdLen) << "/" << String(_dateTime, 8) << "/"
-                      << awsRegion << "/" << String(_awsService, _awsServiceLen) << "/"
-                      << "aws4_request"
-                      << ",";
+                      << awsRegion << "/" << String(_awsService, _awsServiceLen) << "/" << "aws4_request" << ",";
   authorizationHeader << "SignedHeaders=" << signedHeaders << ",";
   authorizationHeader << "Signature=" << base16Signature;
 
