@@ -23,6 +23,7 @@
 
 #include "tscore/ink_config.h"
 #include "proxy/FetchSM.h"
+#include <cstdint>
 #include <cstdio>
 #include "proxy/hdrs/HTTP.h"
 #include "proxy/PluginVC.h"
@@ -259,7 +260,7 @@ FetchSM::dechunk_body()
   //  - TS_FETCH_EVENT_EXT_BODY_READY.
   //  - TS_FETCH_EVENT_EXT_BODY_DONE.
   //
-  if (chunked_handler.process_chunked_content()) {
+  if (auto const [_, done] = chunked_handler.process_chunked_content(); done) {
     return TS_FETCH_EVENT_EXT_BODY_DONE;
   }
 
