@@ -25,7 +25,7 @@ Test transactions and sessions for http1, making sure the two continuations catc
 
 Test.ContinueOnFail = True
 # Define default ATS. Disable the cache to simplify the test.
-ts = Test.MakeATSProcess("ts", select_ports=True, command="traffic_manager", enable_cache=False)
+ts = Test.MakeATSProcess("ts", enable_cache=False)
 server = Test.MakeOriginServer("server")
 
 Test.testName = ""
@@ -81,23 +81,34 @@ tr.StillRunningAfter = ts
 
 # Signal that all the curl processes have completed and poll for done metric
 tr = Test.AddTestRun("Curl Done")
-tr.Processes.Default.Command = (
-    "traffic_ctl plugin msg done done ; "
-    "N=60 ; "
-    "while (( N > 0 )) ; "
-    "do "
-    "sleep 1 ; "
-    'if [[ "$$( traffic_ctl metric get continuations_verify.test.done )" = '
-    '"continuations_verify.test.done 1" ]] ; then exit 0 ; '
-    "fi ; "
-    "let N=N-1 ; "
-    "done ; "
-    "echo TIMEOUT ; "
-    "exit 1")
+tr.Processes.Default.Command = "traffic_ctl plugin msg done done"
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Env = ts.Env
 tr.StillRunningAfter = ts
 
+
+def make_done_stat_ready(tsenv):
+
+    def done_stat_ready(process, hasRunFor, **kw):
+        retval = subprocess.run(
+            "traffic_ctl metric get continuations_verify.test.done",
+            shell=True,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.STDOUT,
+            env=tsenv)
+        return retval.returncode == 0 and b'1' in retval.stdout
+
+    return done_stat_ready
+
+
+watcher = Test.Processes.Process("watcher", "sleep 20")
+
+tr = Test.AddTestRun("Wait for stats")
+tr.Processes.Default.StartBefore(watcher, ready=make_done_stat_ready(ts.Env))
+tr.Processes.Default.Command = "traffic_ctl metric get continuations_verify.test.done"
+tr.Processes.Default.ReturnCode = 0
+tr.Processes.Default.Env = ts.Env
+
 # number of sessions/transactions opened and closed are equal
 tr = Test.AddTestRun("Check Ssn")
 tr.Processes.Default.Command = comparator_command.format('ssn')
